@@ -1,5 +1,8 @@
 #-*- coding: utf-8 -*-
 """
+.. autoclass:: SessionMakerExists
+    :members:
+
 .. autoclass:: BaseModel
     :members:
 """
@@ -8,10 +11,22 @@ from sqlalchemy.orm.collections import InstrumentedList
 
 from sqla_helpers import loading
 from sqla_helpers.process import process_params
+from sqla_helpers.utils import call_if_callable
+
+class SessionMakerExists(Exception):
+    """
+    Exception raised when a session maker is already registered in :class:`sqla_helpers.base_model.BaseModel`
+    """
+    def __unicode__(self):
+        return u'A session maker is already registered.'
+
+    def __str__(self):
+        return 'A session maker is already registered'
+
 
 class ClassProperty(property):
     """
-    Class an alternative use or property decorator in class attribute.
+    Provide a decorator `property` to classemethod
     """
     def __get__(self, cls, owner):
         return self.fget.__get__(None, owner)()
@@ -20,19 +35,27 @@ class ClassProperty(property):
 class BaseModel(object):
     """
     Base Model Class.
-    Provide syntatic sugar for getting object from database.
+    Provide syntatix sugar for getting object from database.
     """
 
+    sessionmaker = None
     process_params = classmethod(process_params)
 
 
     @classmethod
-    def register_sessionmaker(cls, sessionmaker):
+    def register_sessionmaker(cls, sessionmaker, force=False):
         """
         Register the function for making session.
         This registered function mustn't have any parameters.
+        For a globale session, just put the session as parameter.
+        If a session maker is already registered, an exception is raised to avoid conflict.
+        But, if you are sur about what your are doing, you can set `force` parameter to True.
+        It's not advice.
         """
-        cls.sessionmaker = staticmethod(sessionmaker)
+        if cls.sessionmaker is None or force:
+            cls.sessionmaker = staticmethod(sessionmaker)
+        else:
+            raise SessionMakerExists()	
 
 
     @ClassProperty
@@ -41,15 +64,15 @@ class BaseModel(object):
         """
         Call :attr:`BaseModel.sessionmaker` and returns a new session.
 
-        Don't forget to call  :attr:`BaseModel.sessionmaker` in application's initialization.
+        Don't forget to call  :attr:`BaseModel.sessionmaker_maker` in application's initialization.
         """
-        return cls.sessionmaker()
+        return call_if_callable(cls.sessionmaker)
 
 
     @classmethod
     def search(cls, *operator, **criterion):
         """
-        Object seatch with filter pass in arguments.
+        Object search with criterions given in arguments.
         Return a :class:`sqlachemy.orm.query.Query` object.
 
         Filters can be chained.
@@ -73,7 +96,7 @@ class BaseModel(object):
     @classmethod
     def get(cls, *operators, **criterions):
         """
-        Return a object with criterions passed in parameters.
+        Return a object with criterions given in parameters.
         """
         query = cls.search(*operators, **criterions)
         return query.one()
@@ -82,7 +105,7 @@ class BaseModel(object):
     @classmethod
     def all(cls):
         """
-        Return all objects from a same class containts in database.
+        Return all objects from the same class contains in database.
         """
         return cls.search().all()
 
@@ -90,7 +113,7 @@ class BaseModel(object):
     @classmethod
     def filter(cls, *operators, **criterions):
         """
-        Return a list of objects from a class matching criterions passed in parameters.
+        Return a list of objects from a class matching criterions given in parameters.
         """
         query = cls.search(*operators, **criterions)
         return query.all()
@@ -99,10 +122,10 @@ class BaseModel(object):
     @classmethod
     def load(cls, dictionary, hard=False):
         """
-        Return a object from class with attributes got in dictionnary's parameters.
+        Return a object from class with attributes got in dictionary's parameters.
 
-        If all values got from dictionnary form the primary key, the object is
-        loaded from database. Other values are set in the loading object.
+        If all the primary key are found in the dictionary, the object is
+        loaded from database. Otherwise, values are set in the loading object.
 
         .. code-block:: python
 
@@ -117,7 +140,7 @@ class BaseModel(object):
             'Awesome Treatment'
 
         If `hard` parameter is True, an axception is raised if a value isn't found
-        in parameter's dictionnary.
+        in parameter's dictionary.
         """
 
         # On détermine si on doit charger l'instance depuis la base ou non.
@@ -181,7 +204,7 @@ class BaseModel(object):
 
     def dump(self, excludes=[], depth=2):
         """
-        Return object as dictionnary with dependencies.
+        Return object as dictionary with dependencies.
 
         `Depth` limits the recursion.
 
