@@ -8,10 +8,10 @@ from sqla_helpers.tests.class_test import Treatment, Status
 from sqla_helpers.base_model import BaseModel
 from sqla_helpers.tests.class_test import metadata
 
+engine = create_engine('sqlite://')
+session = sessionmaker(bind=engine)()
 
 def populate():
-	engine = create_engine('sqlite://', echo=True)
-	session = sessionmaker(bind=engine)()
 	BaseModel.register_sessionmaker(lambda: session)
 	metadata.create_all(engine)
 	status = [Status(u'ok'), Status(u'ko')]
@@ -31,5 +31,4 @@ def test_load():
 	assert status.name == u'plop'
 	status = Status.load({'id': 1})
 	assert status.id == 1 
-	print status.name
 	assert status.name == u'ok'
